@@ -247,7 +247,7 @@ static int _gnutls_find_acceptable_client_cert(gnutls_session session,
 	    _gnutls_get_cred(session->key, GNUTLS_CRD_CERTIFICATE, NULL);
 	if (cred == NULL) {
 		gnutls_assert();
-		return GNUTLS_E_INSUFICIENT_CREDENTIALS;
+		return GNUTLS_E_INSUFFICIENT_CREDENTIALS;
 	}
 
 	/* If we have no callback.
@@ -646,7 +646,7 @@ int _gnutls_proc_x509_server_certificate(gnutls_session session,
 	    _gnutls_get_cred(session->key, GNUTLS_CRD_CERTIFICATE, NULL);
 	if (cred == NULL) {
 		gnutls_assert();
-		return GNUTLS_E_INSUFICIENT_CREDENTIALS;
+		return GNUTLS_E_INSUFFICIENT_CREDENTIALS;
 	}
 
 
@@ -782,7 +782,7 @@ int _gnutls_proc_openpgp_server_certificate(gnutls_session session,
 	    _gnutls_get_cred(session->key, GNUTLS_CRD_CERTIFICATE, NULL);
 	if (cred == NULL) {
 		gnutls_assert();
-		return GNUTLS_E_INSUFICIENT_CREDENTIALS;
+		return GNUTLS_E_INSUFFICIENT_CREDENTIALS;
 	}
 
 	if ((ret =
@@ -988,7 +988,7 @@ int _gnutls_proc_cert_cert_req(gnutls_session session, opaque * data,
 	    _gnutls_get_cred(session->key, GNUTLS_CRD_CERTIFICATE, NULL);
 	if (cred == NULL) {
 		gnutls_assert();
-		return GNUTLS_E_INSUFICIENT_CREDENTIALS;
+		return GNUTLS_E_INSUFFICIENT_CREDENTIALS;
 	}
 
 	if ((ret =
@@ -1186,7 +1186,7 @@ int _gnutls_gen_cert_server_cert_req(gnutls_session session,
 	    _gnutls_get_cred(session->key, GNUTLS_CRD_CERTIFICATE, NULL);
 	if (cred == NULL) {
 		gnutls_assert();
-		return GNUTLS_E_INSUFICIENT_CREDENTIALS;
+		return GNUTLS_E_INSUFFICIENT_CREDENTIALS;
 	}
 
 	size = CERTTYPE_SIZE + 2;	/* 2 for gnutls_certificate_type + 2 for size of rdn_seq 
@@ -1213,7 +1213,7 @@ int _gnutls_gen_cert_server_cert_req(gnutls_session session,
 	if (session->security_parameters.cert_type == GNUTLS_CRT_X509 &&
 		session->internals.ignore_rdn_sequence == 0) {
 		_gnutls_write_datum16(pdata, cred->x509_rdn_sequence);
-		pdata += cred->x509_rdn_sequence.size + 2;
+		/* pdata += cred->x509_rdn_sequence.size + 2; */
 	}
 
 	return size;
@@ -1238,7 +1238,7 @@ int _gnutls_find_apr_cert(gnutls_session session,
 		*apr_cert_list = NULL;
 		*apr_pkey = NULL;
 		*apr_cert_list_length = 0;
-		return GNUTLS_E_INSUFICIENT_CREDENTIALS;
+		return GNUTLS_E_INSUFFICIENT_CREDENTIALS;
 	}
 
 	if (session->security_parameters.entity == GNUTLS_SERVER) {
@@ -1248,7 +1248,7 @@ int _gnutls_find_apr_cert(gnutls_session session,
 			*apr_cert_list_length = 0;
 			*apr_pkey = NULL;
 			gnutls_assert();	/* this is not allowed */
-			return GNUTLS_E_INSUFICIENT_CREDENTIALS;
+			return GNUTLS_E_INSUFFICIENT_CREDENTIALS;
 		} else {
 			/* find_cert_list_index() has been called before.
 			 */
@@ -1259,7 +1259,7 @@ int _gnutls_find_apr_cert(gnutls_session session,
 				*apr_cert_list_length = 0;
 				*apr_pkey = NULL;
 				gnutls_assert();
-				return GNUTLS_E_INSUFICIENT_CREDENTIALS;
+				return GNUTLS_E_INSUFFICIENT_CREDENTIALS;
 			} else {
 				*apr_cert_list = cred->cert_list[ind];
 				*apr_cert_list_length =
@@ -1333,16 +1333,15 @@ static int _gnutls_server_find_cert_list_index(gnutls_session session,
 					       requested_algo)
 {
 	uint i, j;
-	int index = -1;
+	int index;
 	const gnutls_certificate_credentials cred;
 	int my_certs_length;
-	int *ij_map = NULL;
 
 	cred =
 	    _gnutls_get_cred(session->key, GNUTLS_CRD_CERTIFICATE, NULL);
 	if (cred == NULL) {
 		gnutls_assert();
-		return GNUTLS_E_INSUFICIENT_CREDENTIALS;
+		return GNUTLS_E_INSUFFICIENT_CREDENTIALS;
 	}
 
 	index = -1;		/* default is use no certificate */
@@ -1365,17 +1364,19 @@ static int _gnutls_server_find_cert_list_index(gnutls_session session,
 	if (session->internals.server_cert_callback != NULL && cred->ncerts > 0) {	
 		/* use the callback to get certificate 
 		 */
-		gnutls_datum *my_certs = NULL;
+		gnutls_datum *my_certs;
+		int *ij_map;
 
-		my_certs =
-		    gnutls_malloc(cred->ncerts * sizeof(gnutls_datum));
-		if (my_certs == NULL)
-			goto clear;
 		my_certs_length = cred->ncerts;
+		my_certs =
+		    gnutls_malloc(my_certs_length * sizeof(gnutls_datum));
+		if (my_certs == NULL)
+			goto out;
 
 		/* put our certificate's issuer and dn into cdn, idn
 		 */
-		ij_map = gnutls_malloc(sizeof(int) * cred->ncerts);
+		ij_map = gnutls_malloc(my_certs_length * sizeof(int));
+		if (ij_map == NULL) goto cleanup_certs;
 
 		j = 0;
 		for (i = 0; i < cred->ncerts; i++) {
@@ -1405,11 +1406,13 @@ static int _gnutls_server_find_cert_list_index(gnutls_session session,
 		if (index != -1)
 			index = ij_map[index];
 
-	      clear:
-		gnutls_free(my_certs);
 		gnutls_free(ij_map);
+		cleanup_certs:
+		gnutls_free(my_certs);
+
 	}
 
+	out:
 	/* store the index for future use, in the handshake.
 	 * (This will allow not calling this callback again.)
 	 */
