@@ -288,12 +288,12 @@ int gnutls_certificate_client_get_request_status(gnutls_session session)
   *
   **/
 int gnutls_fingerprint(gnutls_digest_algorithm algo, const gnutls_datum* data, 
-	unsigned char* result, int* result_size)
+	unsigned char* result, size_t* result_size)
 {
 	GNUTLS_HASH_HANDLE td;
 	int hash_len = _gnutls_hash_get_algo_len(algo);
 	
-	if (hash_len < 0 || hash_len > *result_size ||
+	if (hash_len < 0 || (uint)hash_len > *result_size ||
 		result==NULL) 
 	{
 		*result_size = hash_len;
