@@ -16,6 +16,10 @@
  * 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#include <config.h>
+
+#ifdef ENABLE_OPENSSL
+
 #include <gnutls/gnutls.h>
 #include <gcrypt.h>
 #include <stdio.h>
@@ -965,3 +969,5 @@ unsigned char *RIPEMD160(const unsigned char *buf, unsigned long len,
     
     return md;
 }
+
+#endif
