@@ -24,17 +24,11 @@
 #include <errno.h>
 #include <stdlib.h>
 #include <sys/types.h>
-#include <sys/socket.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
 #include <string.h>
-#include <unistd.h>
 #include <gnutls/gnutls.h>
 #include <gnutls/extra.h>
 #include <gnutls/x509.h>
 #include <sys/time.h>
-#include <signal.h>
-#include <netdb.h>
 #include "common.h"
 #include "cli-gaa.h"
 
@@ -270,8 +264,12 @@ int main(int argc, char **argv)
 		fprintf(stderr, "No hostname given\n");
 		exit(1);
 	}
+	
+	sockets_init();
 
+#ifndef _WIN32
 	signal(SIGPIPE, SIG_IGN);
+#endif
 
 	init_global_tls_stuff();
 
@@ -297,7 +295,6 @@ int main(int argc, char **argv)
 		perror("inet_ntop()");
 		return(1);
 	}
-
 	fprintf(stderr, "Connecting to '%s:%d'...\n", buffer, port);
 
 	err = connect(sd, (SA *) & sa, sizeof(sa));
@@ -377,7 +374,9 @@ int main(int argc, char **argv)
 
 	printf("\n- Simple Client Mode:\n\n");
 
+#ifndef _WIN32
 	signal (SIGALRM, &starttls_alarm);
+#endif
 
 	/* do not buffer */
 	setbuf(stdin, NULL);
