@@ -35,16 +35,39 @@ int main (int argc, char **argv)
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
-#include <unistd.h>
-#include "crypt-gaa.h"
 #include <gnutls/gnutls.h>
 #include <gnutls/extra.h>
 #include <gcrypt.h> /* for randomize */
-#include <pwd.h>
+#include <crypt-gaa.h>
+
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <unistd.h>
 
+#ifndef _WIN32
+# include <pwd.h>
+# include <unistd.h>
+#else
+# include <windows.h>
+#endif
+
+#ifdef _WIN32
+
+# define getpass read_str
+
+static const char* read_str( const char* input_str)
+{
+static char input[128];
+
+	fputs( input_str, stderr);
+	fgets( input, sizeof(input), stdin);
+	
+	input[strlen(input)-1] = 0;
+
+	if (strlen(input)==0) return NULL;
+
+	return input;
+}
+#endif
 
 #define _MAX(x,y) (x>y?x:y)
 
@@ -229,7 +252,7 @@ char *pos;
 
 	/* copy salt, and null terminate after the ':' */
 	strcpy( _salt, salt);
-	pos = index(_salt, ':');
+	pos = strchr(_salt, ':');
 	if (pos!=NULL) *pos = 0;
 
 	/* convert salt to binary. */
@@ -302,7 +325,7 @@ char *p;
 }
 
 /* accepts password file */
-static int find_index(char* username, char* file) {
+static int find_strchr(char* username, char* file) {
 FILE * fd;
 char *pos;
 char line[5*1024];
@@ -323,7 +346,7 @@ unsigned int i;
 		}
 		if (strncmp(username, line, _MAX(i,strlen(username)) )  == 0) {
 			/* find the index */
-			pos = rindex(line, ':');
+			pos = strrchr(line, ':');
 			pos++;
 			fclose(fd);
 			return atoi(pos);
@@ -346,7 +369,7 @@ int verify_passwd(char *conffile, char *tpasswd, char *username, char *passwd)
 	int iindex;
 	char *p, *pos;
 
-	iindex = find_index( username, tpasswd);
+	iindex = find_strchr( username, tpasswd);
 	if (iindex==-1) {
 		fprintf(stderr, "Cannot find '%s' in %s\n", username, tpasswd);
 		return -1;
@@ -393,7 +416,7 @@ int verify_passwd(char *conffile, char *tpasswd, char *username, char *passwd)
 		if (strncmp(username, line, _MAX(i,strlen(username)) )  == 0) {
 			char* verifier_pos, *salt_pos;
 
-			pos = index(line, ':');
+			pos = strchr(line, ':');
 			fclose(fd);
 			if (pos==NULL) {
 				fprintf(stderr, "Cannot parse conf file '%s'\n", conffile);
@@ -403,7 +426,7 @@ int verify_passwd(char *conffile, char *tpasswd, char *username, char *passwd)
 			verifier_pos = pos;
 
 			/* Move to the salt */
-			pos = index(pos, ':');
+			pos = strchr(pos, ':');
 			if (pos==NULL) {
 				fprintf(stderr, "Cannot parse conf file '%s'\n", conffile);
 				return -1;
@@ -459,6 +482,7 @@ int main(int argc, char **argv)
 		info.passwd_conf = KPASSWD_CONF;
 
 	if (info.username == NULL) {
+#ifndef _WIN32
 		pwd = getpwuid(getuid());
 
 		if (pwd == NULL) {
@@ -467,6 +491,10 @@ int main(int argc, char **argv)
 		}
 
 		info.username = pwd->pw_name;
+#else
+		fprintf(stderr, "Please specify a user\n");
+		return -1;
+#endif
 	}
 
 	salt = 16;
@@ -614,7 +642,7 @@ int crypt_int(char *username, char *passwd, int salt_size,
 			p = fgets( line, sizeof(line)-1, fd2);
 			if (p==NULL) break;
 			
-			pp = index( line, ':');
+			pp = strchr( line, ':');
 			if (pp==NULL) continue;
 			
 			if ( strncmp( p, username, _MAX(strlen(username), (unsigned int)(pp-p)) ) == 0 ) {
@@ -654,7 +682,7 @@ static int read_conf_values(gnutls_datum * g, gnutls_datum * n, char *str)
 
 	index = atoi(str);
 
-	p = rindex(str, ':');	/* we have g */
+	p = strrchr(str, ':');	/* we have g */
 	if (p == NULL) {
 		return -1;
 	}
@@ -676,7 +704,7 @@ static int read_conf_values(gnutls_datum * g, gnutls_datum * n, char *str)
 	}
 
 	/* now go for n - modulo */
-	p = rindex(str, ':');	/* we have n */
+	p = strrchr(str, ':');	/* we have n */
 	if (p == NULL) {
 		return -1;
 	}
