@@ -23,17 +23,12 @@
 #include <errno.h>
 #include <stdlib.h>
 #include <sys/types.h>
-#include <sys/socket.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
 #include <string.h>
-#include <unistd.h>
 #include <gnutls/gnutls.h>
 #include <gnutls/extra.h>
 #include <sys/time.h>
-#include <signal.h>
-#include <netdb.h>
 #include <tests.h>
+#include <common.h>
 #include <tls_test-gaa.h>
 
 #ifndef SHUT_WR
@@ -100,7 +95,7 @@ static const TLS_TEST tls_tests[] = {
 	{ "for certificate information", test_certificate, "", "", "" },
 	{ "for trusted CAs", test_server_cas, "", "", "" },
 	{ "whether the server understands TLS closure alerts", test_bye, "yes", "no", "partially"},
-	/* the fact that is after the closure alert test matter.
+	/* the fact that is after the closure alert test does matter.
 	 */
 	{ "whether the server supports session resumption", test_session_resume2, "yes", "no", "dunno"},
 	{ "for export-grade ciphersuite support", test_export, "yes", "no", "dunno" },
@@ -124,6 +119,7 @@ static const TLS_TEST tls_tests[] = {
 };
 
 static int tt = 0;
+const char* ip;
 
 #define CONNECT() \
 		sd = socket(AF_INET, SOCK_STREAM, 0); \
@@ -132,8 +128,8 @@ static int tt = 0;
 		sa.sin_family = AF_INET; \
 		sa.sin_port = htons(port); \
 		sa.sin_addr.s_addr = *((unsigned int *) server_host->h_addr); \
-		inet_ntop(AF_INET, &sa.sin_addr, buffer, MAX_BUF); \
-		if (tt++ == 0) printf("Connecting to '%s:%d'...\n", buffer, port); \
+		ip = inet_ntop(AF_INET, &sa.sin_addr, buffer, MAX_BUF); \
+		if (tt++ == 0) printf("Connecting to '%s:%d'...\n", ip, port); \
 		err = connect(sd, (SA *) & sa, sizeof(sa)); \
 		ERR(err, "connect")
 
@@ -152,7 +148,11 @@ int main(int argc, char **argv)
 
 	gaa_parser(argc, argv);
 
+#ifndef _WIN32
 	signal(SIGPIPE, SIG_IGN);
+#endif
+
+        sockets_init();
 
 	if (gnutls_global_init() < 0) {
 		fprintf(stderr, "global state initialization error\n");
@@ -218,7 +218,7 @@ int main(int argc, char **argv)
 			printf(" %s\n", tls_tests[i].suc_str);
 			if (i==0) tls1_ok = 1;
 			if (i==1) ssl3_ok = 1;
-		} else if (ret==FAILED)
+		} else if (ret==GFAILED)
 			printf(" %s\n", tls_tests[i].fail_str);
 		else printf(" %s\n", tls_tests[i].unsure_str);
 
